@@ -2,12 +2,34 @@ package Test2::API;
 use strict;
 use warnings;
 
-our $VERSION = '0.000031';
+our $VERSION = '0.000036';
 
 my $INST;
+my $ENDING = 0;
+sub _set_is_end { $ENDING = 1 }
+
 use Test2::API::Instance(\$INST);
 # Set the exit status
-END { $INST->set_exit() }
+END {
+    _set_is_end(); # See gh #16
+    $INST->set_exit();
+}
+
+# See gh #16
+{
+    no warnings;
+    INIT { eval 'END { _set_is_end() }; 1' or die $@ }
+}
+
+BEGIN {
+    no warnings 'once';
+    if($] ge '5.014' || $ENV{T2_CHECK_DEPTH} || $Test2::API::DO_DEPTH_CHECK) {
+        *DO_DEPTH_CHECK = sub() { 1 };
+    }
+    else {
+        *DO_DEPTH_CHECK = sub() { 0 };
+    }
+}
 
 use Test2::Util::Trace();
 
@@ -216,18 +238,24 @@ sub context {
     $_->(\%params) for @$ACQUIRE_CBS;
     map $_->(\%params), @{$hub->{_context_acquire}} if $hub->{_context_acquire};
 
+    # This is for https://github.com/Test-More/Test2/issues/16
+    # and https://rt.perl.org/Public/Bug/Display.html?id=127774
+    my $phase = ${^GLOBAL_PHASE} || 'NA';
+    my $end_phase = $ENDING || $phase eq 'END' || $phase eq 'DESTRUCT';
+
     my $level = 1 + $params{level};
-    my ($pkg, $file, $line, $sub) = caller($level);
-    unless ($pkg) {
+    my ($pkg, $file, $line, $sub) = $end_phase ? caller(0) : caller($level);
+    unless ($pkg || $end_phase) {
         confess "Could not find context at depth $level" unless $params{fudge};
         ($pkg, $file, $line, $sub) = caller(--$level) while ($level >= 0 && !$pkg);
     }
 
     my $depth = $level;
-    $depth++ while caller($depth + 1) && (!$current || $depth <= $current->{_depth} + $params{wrapped});
+    $depth++ while DO_DEPTH_CHECK && !$end_phase && (!$current || $depth <= $current->{_depth} + $params{wrapped}) && caller($depth + 1);
     $depth -= $params{wrapped};
+    my $depth_ok = !DO_DEPTH_CHECK || $end_phase || !$current || $current->{_depth} < $depth;
 
-    if ($current && $params{on_release} && $current->{_depth} < $depth) {
+    if ($current && $params{on_release} && $depth_ok) {
         $current->{_on_release} ||= [];
         push @{$current->{_on_release}} => $params{on_release};
     }
@@ -243,7 +271,7 @@ sub context {
             _is_spawn   => [$pkg, $file, $line, $sub],
         },
         'Test2::API::Context'
-    ) if $current && $current->{_depth} < $depth;
+    ) if $current && $depth_ok;
 
     # Handle error condition of bad level
     if ($current) {
@@ -252,7 +280,7 @@ sub context {
                 unless $current->{_is_canon};
 
             _depth_error($current, [$pkg, $file, $line, $sub, $depth])
-                unless $current->{_depth} < $depth;
+                unless $depth_ok;
         }
 
         $current->release if $current->{_is_canon};
@@ -621,6 +649,12 @@ what you can and cannot do with a context once it is obtained.
 B<Note> This function will throw an exception if you ignore the context object
 it returns.
 
+B<Note> On perls 5.14+ a depth check is used to insure there are no context
+leaks. This cannot be safely done on older perls due to
+L<https://rt.perl.org/Public/Bug/Display.html?id=127774>
+You can forcefully enable it either by setting C<$ENV{T2_CHECK_DEPTH} = 1> or
+C<$Test2::API::DO_DEPTH_CHECK = 1> B<BEFORE> loading L<Test2::API>.
+
 =head3 OPTIONAL PARAMETERS
 
 All parameters to C<context> are optional.
