@@ -2,7 +2,7 @@ package Test2::Formatter::TAP;
 use strict;
 use warnings;
 
-our $VERSION = '0.000031';
+our $VERSION = '0.000036';
 
 use Test2::Util::HashBase qw{
     no_numbers handles _encoding
@@ -105,8 +105,8 @@ sub write {
 sub _open_handles {
     my $self = shift;
 
-    open( my $out, ">&STDOUT" ) or die "Can't dup STDOUT:  $!";
-    open( my $err, ">&STDERR" ) or die "Can't dup STDERR:  $!";
+    open( my $out, '>&', STDOUT ) or die "Can't dup STDOUT:  $!";
+    open( my $err, '>&', STDERR ) or die "Can't dup STDERR:  $!";
 
     _autoflush($out);
     _autoflush($err);
